# pyg-base

pip install from https://pypi.org/project/pyg-base/

base contains a range of various utilities that help quick research. 

* date functions: dt, drange, calendar
* extending the Dict: ulist, Dict, named_dict, tree
* graph calculations: cell
* dictable
* various decorators: try_none, loop(list), timer, etc.
* zipper: a safer version of zip
* pandas utilities: df_reindex, df_sync, df_fillna, nona, df_slice, add_, sub_, mul_, div_, pow_
* async waiter to allow awaiting dicts and lists of awaitables more easily
